from flask import Flask

from neocortex import auth, api
from neocortex.api import views as apiviews
from neocortex.extensions import db, jwt, migrate, neo4j


def create_app(config=None, testing=False, cli=False):
    """Application factory, used to create application
    """
    app = Flask('neocortex')

    configure_app(app, testing)
    configure_extensions(app, cli)
    register_blueprints(app)

    return app

def configure_app(app, testing=False):
    """set configuration for application
    """
    # default configuration
    app.config.from_object('neocortex.config')

    if testing is True:
        # override with testing config
        app.config.from_object('neocortex.configtest')
    else:
        # override with env variable, fail silently if not set
        app.config.from_envvar("NEOCORTEX_CONFIG", silent=True)


def configure_extensions(app, cli):
    """configure flask extensions
    """
    db.init_app(app)
    jwt.init_app(app)
    
    if cli is True:
        migrate.init_app(app, db)
        
    #graph_indexes = {'Species': py2neo.Node}
    #neo4j.init_app(app, graph_indexes)
    
    neo4j.init_app(app)


def register_blueprints(app):
    """register all blueprints for application
    """
    app.register_blueprint(auth.views.blueprint)
    app.register_blueprint(apiviews.blueprint_one)
